////-------------------------------------------------------------------
//
//  This code is copyright 2010 by G5 Entertainment AB.
//  Any unauthorized usage, either in part or in whole of this code
//  is strictly prohibited. Violators WILL be prosecuted to the
//  maximum extent allowed by law.
//
//-------------------------------------------------------------------
//
//         File: jquery.touchFire.js
//  Description:
//       Author: Voronoy S. (sergey.voronoy@g5e.com)
(function($) {
  var
  ignoreTags = ['textarea', 'input', 'select', 'button'],
  SUPPORTS_TOUCH = 'ontouchstart' in window,
  SUPPORTS_POINTER_IE10 = window.navigator.msPointerEnabled && !window.navigator.pointerEnabled,
  SUPPORTS_POINTER = window.navigator.pointerEnabled || window.navigator.msPointerEnabled,
  runing = false,
  touchevents = {
    start: SUPPORTS_POINTER ? (SUPPORTS_POINTER_IE10 ? 'MSPointerDown' : 'pointerdown') : 'touchstart',
    move: SUPPORTS_POINTER ? (SUPPORTS_POINTER_IE10 ? 'MSPointerMove' : 'pointermove') : 'touchmove',
    cancel: SUPPORTS_POINTER ? (SUPPORTS_POINTER_IE10 ? 'MSPointerCancel' : 'pointercancel') : 'touchcancel',
    end: SUPPORTS_POINTER ? (SUPPORTS_POINTER_IE10 ? 'MSPointerUp' : 'pointerup') : 'touchend'
  },
  mouseevents = {
    start: 'mousedown',
    move: 'mousemove',
    end: 'mouseup dragstart'
  },
  dragevents = {
    start: 'dragstart',
    move: 'dragmove',
    end: 'dragend'
  },
  data = {},
  timerClick,
  blockClick = false,
  userAgent = navigator.userAgent.toLowerCase(),
  isAndroid404 = (userAgent.indexOf(' android 4.0') > -1);

  $.fn.touchFire = function(settings){
    settings = jQuery.extend({
      swipeLeft: null,
      swipeRight: null,
      swipeUp: null,
      swipeDown: null,
      move: null,
      end: null,
      threshold: 75
    }, settings);
    var jQueryMatchedObj = $(this); // This, in this context, refer to jQuery object
    function touchStart(e) {
      e = getOriginal(e);
      if (ignoreTags.indexOf(e.target.tagName.toLowerCase()) != -1)
        return;
      if (runing)
      {
        touchCancel();
        return;
      }
      runing = true;
      var touch = e.changedTouches[0];
      data.startX = touch.pageX;
      data.startY = touch.pageY;
      data.identifier = touch.identifier;
      data.prevent = false;
      jQueryMatchedObj.each(function () {
        if (SUPPORTS_TOUCH)
        {
          jQuery.event.add(this, touchevents.move + '.' + data.identifier, touchMove);
          jQuery.event.add(this, touchevents.end + '.' + data.identifier, touchEnd);
          jQuery.event.add(this, touchevents.cancel + '.' + data.identifier, touchCancel);
        }
      });
    }
    function touchMove(e) {
      e = getOriginal(e);
      setDataFromTouch(e);
      checkTreshold(e);
      if (typeof settings.move == 'function')
        settings.move(data);
      //if (isAndroid404)
        e.preventDefault();
    }
    function touchEnd(e) {
      e = getOriginal(e);
      setDataFromTouch(e);
      touchCancel(e);
    }
    function touchCancel(e) {
      var flag = false;
      if (SUPPORTS_TOUCH)
      {
        var nameSpace = data.identifier;
        if (typeof e != 'undefined' && SUPPORTS_TOUCH && 'handleObj' in e && 'namespace' in e.handleObj)
        {
          nameSpace = e.handleObj.namespace;
          if (e.handleObj.type == touchevents.cancel)
          {
            flag = true;
            setDataFromTouch(e);
            e.preventDefault();
          }
        }
        jQueryMatchedObj.each(function () {
          jQuery.event.remove(this, touchevents.move + '.' + nameSpace);
          jQuery.event.remove(this, touchevents.end + '.' + nameSpace);
          jQuery.event.remove(this, touchevents.cancel + '.' + nameSpace);
        });
      }
      fireFunction(e, flag);
      runing = false;
      data = {};
      return false;
    }
    function mouseStart(e){
      e = getOriginal(e);
      if (!isLeftButton(e)) { return; }
      data.startX = e.pageX;
      data.startY = e.pageY;
      data.prevent = false;
      jQueryMatchedObj.each(function () {
        jQuery.event.add(this, mouseevents.move, mouseMove);
        jQuery.event.add(this, mouseevents.end, mouseEnd);
      });
    }
    function mouseMove(e) {
      clearTimeout(timerClick);
      e = getOriginal(e);
      setDataFromMouse(e);
      checkTreshold(e);
      blockClick = data.prevent;
    }
    function mouseEnd(e) {
      e = getOriginal(e);
      setDataFromMouse(e);
      if (e.type.toLowerCase() == dragevents.start)
      {
        e.preventDefault();
        jQueryMatchedObj.each(function () {
          jQuery.event.add(this, dragevents.move, mouseMove);
          jQuery.event.add(this, dragevents.end, dragEnd);
        });
      }
      else
      {
        fireFunction(e);
        mouseCancel();
      }
    }
    function dragEnd(e) {
      e = getOriginal(e);
      setDataFromMouse(e);
      fireFunction(e);
      mouseCancel();
    }
    function mouseCancel() {
      jQueryMatchedObj.each(function () {
        jQuery.event.remove(this, mouseevents.move);
        jQuery.event.remove(this, mouseevents.end);
        jQuery.event.remove(this, dragevents.move);
        jQuery.event.remove(this, dragevents.end);
      });
      data = {};
      timerClick = setTimeout(function(){blockClick = false}, 500);
    }
    function getOriginal(e) {
      return ('originalEvent' in e) ? e.originalEvent : e;
    }
    function setDataFromTouch(e) {
      e = getOriginal(e);
      var touch = e.changedTouches[0];
      data.endX = touch.pageX;
      data.endY = touch.pageY;
      data.distX = data.endX - data.startX;
      data.distY = data.endY - data.startY;
    }
    function setDataFromMouse(e) {
      data.endX = e.pageX;
      data.endY = e.pageY;
      data.distX = data.endX - data.startX;
      data.distY = data.endY - data.startY;
    }
    function testTreshold() {
      return ((data.distX * data.distX) + (data.distY * data.distY) > (settings.threshold * settings.threshold));
    }
    function checkTreshold(e) {
      if (testTreshold())
        data.prevent = true;
      if (data.prevent)
        e.preventDefault();
    }
    function fireFunction(e, flag) {
      flag = !!flag;
      if (testTreshold() || flag)
      {
        e.preventDefault();
        if (Math.abs(data.distX) > Math.abs(data.distY)) {
          if (data.distX < 0)
          {
            if (typeof settings.swipeLeft == 'function')
              settings.swipeLeft(data);
          }
          else {
            if (typeof settings.swipeRight == 'function')
              settings.swipeRight(data);
          }
        }
        else if (Math.abs(data.distX) < Math.abs(data.distY))
        {
          if (data.distY < 0)
          {
            if (typeof settings.swipeUp == 'function')
              settings.swipeUp(data);
          }
          else {
            if (typeof settings.swipeDown == 'function')
              settings.swipeDown(data);
          }
        }
      }
      if (typeof settings.end == 'function')
        settings.end(data);
    }
    function isLeftButton(e) {
      return (e.which === 1 && !e.ctrlKey && !e.altKey);
    }
    function _init() {
      jQueryMatchedObj.on('click', function(){
        return !blockClick;
      }).each(function () {
        if (SUPPORTS_TOUCH)
          jQuery.event.add(this, touchevents.start + '.swipe', touchStart);
        jQuery.event.add(this, mouseevents.start + '.swipe', mouseStart);
      });
    }
    _init($(this));
    return this;
  };
})(jQuery);