//-------------------------------------------------------------------
//
//  This code is copyright 2010 by G5 Entertainment AB.
//  Any unauthorized usage, either in part or in whole of this code
//  is strictly prohibited. Violators WILL be prosecuted to the
//  maximum extent allowed by law.
//
//-------------------------------------------------------------------
//
//         File: lockit.js
//  Description: 
//       Author: Davidovich V. (ringo@g5software.com)

var count_setZoomed = 0;
var timer_setZoomed = null;

String.prototype.get = function(p)
{
  return (match = this.match(new RegExp("[?|&]?" + p + "=([^&]*)"))) ? match[1] : null;
}

var lockitXHR;

function lockitLoadLangs(_title)
{
  if (!lockitXHR)
    lockitXHR = new XMLHttpRequest();

  with (lockitXHR)
  {
    open("GET", _title + ".txt", false);
    send(null);

    if (responseText)
    {
      try
      {
        return JSON.parse(responseText.replace(/[\r\n]/g, ''));
      }
      catch (e)
      {
        console.log(e);
      }
    }
  }

  return null;
}

function lockitGetLang()
{
  var lang = window.location.search.get("lang");
  
  if (!lang)
    lang = window.localStorage.getItem("xpromo.lang");

  if (!lang)
  {
    if (navigator.userLanguage)
      lang = navigator.userLanguage;
    else
    if (navigator.language)
      lang = navigator.language.split("-")[0];
  }
  window.localStorage.setItem("xpromo.lang", lang);
  return lang;  
}

function lockitGet(_data)
{
  if (_data)
  {
    var english = _data["lang.en"];
    var lang    = lockitGetLang();
    var result  = _data["lang." + lang];

    if (!result)
    {
      result = english;
      lang   = "en";
    }
    else
    if (result != english)
    {
      for (var k in english)
        if (!result.hasOwnProperty(k))
          result[k] = english[k];
    }

    if (result)
      result.lang = lang;

    return result;
  }

  return null;
}

var lockitCache = {};

function lockitLoad(_title)
{
  var result = lockitCache[_title];
  if (result == undefined)
  {
    result = lockitGet(lockitLoadLangs(_title));;
    lockitCache[_title] = result;
  }

  return result;
}

function lockitRenderData(_data)
{
  if (_data)
  {
    for (var sel in _data)
    {
      var elements = document.querySelectorAll(sel);
      for (var i in elements)
        elements[i].innerHTML = _data[sel];
    }
  }

  return _data;
}

var lockitThis = lockitLoad(document.title);
if(lockitThis != null)
{
  if ("title" in lockitThis)
  {
    document.title = lockitThis["title"];
    delete lockitThis["title"];
  }
}

function lockitRender()
{
  var userAgent = navigator.userAgent.toLowerCase();
  if(userAgent.indexOf("android 4") != -1)
  {
    document.body.style["font-size"] = "100%";
  }
  return lockitRenderData(lockitThis);
}

//
// Common utils
//

// Adds class name to element
function addClass(element, elClass) 
{
  var curr = element.className;
  if (!new RegExp(("(^|\\s)" + elClass + "(\\s|$)"), "i").test(curr)) 
  {
    element.className = curr + ((curr.length > 0) ? " " : "") + elClass;
  }
  return element;
}

// Removes class name from element
function removeClass(element, elClass) 
{
  if (elClass) 
  {
    element.className = element.className.replace(elClass, "");
  }
  else 
  {
    element.className = "";
    element.removeAttribute("class");
  }
  return element;
}

function getPlatformFromId(id)
{
  if(!id) return 'winrt';
  
  var temp_array = id.split('.');
  if (inArray('android', temp_array) == true)
  {
    return 'android'
  }
  else
  if (inArray('hd', temp_array) == true)
  {
    return 'ipad'
  }
  else
  if (inArray('mac', temp_array) == true)
  {
    return 'mac'
  }
  else
  if (inArray('pc', temp_array) == true)
  {
    return 'pc'
  }
  else
  if (inArray('winrt', temp_array) == true)
  {
    return 'winrt'
  }
  else
  if (inArray('winphone', temp_array) == true)
  {
    return 'winphone'
  }
  else
  {
    return 'iphone'
  }
}

function inArray(needle, haystack)
{ 
  for(var i in haystack)
  {
    if (haystack[i] == needle) 
      return true;
  }
  return false;
}

function iconNameFor(game_id, variant)
{
  var result = 'icon';
  if (variant)
    result += variant;

  var platform = getPlatformFromId(game_id);
  if (platform == 'mac')
    result += '.png';
  else
    result += '.jpg';

  result += "?v=1";
  return result;
}

function iconStyleFor(game_id, scale)
{
  var result = '', platform = getPlatformFromId(game_id);
  if (!scale)
    scale = 1;

  if (platform == 'android')
  {
    result = ';-webkit-border-radius: ' + scale * 4 + 'px;';
  }
  else 
  if (platform == 'mac' || platform == 'winrt' || platform == 'winphone')
  {
    result = ';background-color: transparent;box-shadow: none; -webkit-box-shadow: none; border-radius: 0; -webkit-border-radius: 0; border-bottom-width: 0;';
  }
  return result;
}

function simulateClick(_href)
{
  if (window.KDWebWindow &&
      window.KDWebWindow.shouldLoad)
    if(!window.KDWebWindow.shouldLoad(_href))
      return undefined;

  return window.location.href = _href;
}

function simulateClickExt(_href)
{
  return simulateClick("@ext(" + _href + ")");
}

function xpromoReport(_log)
{
  if (userAgent.indexOf("trident") != -1)
  {
    window.external.notify("@log(" + _log + ")");
  }
  else
  {
    var el = document.createElement('iframe');

    el.style.marginTop = "10px";
    el.style.display = "none";
    el.src = "@log(" + _log + ")";

    document.body.appendChild(el);

    setTimeout(function(){
      el.parentNode.removeChild(el);
    }, 500);
  }
}

function setZoomed(a, b) {
  if (a == undefined || a == null)
    a = 0;
  if (b == undefined || b == null)
    b = 0;
  var zm = 0;
  var userAgent = navigator.userAgent.toLowerCase();
  var inHeight = window.innerHeight;
  var inWidth = window.innerWidth;
  if (b == 1)
  {
    zm = window.localStorage.getItem('xpromo.ui.zoom');
    if (zm == null || zm == 0)
    {
      a++;
      if (a < 15)
      {
        setTimeout('setZoomed(' + a + ',' + b + ')', 500);
      }
      else
      {
        timeoutSetZoomed(b);
      }
      return false;
    }
    else
    {
      var pixelRatio = window.devicePixelRatio;
      if (pixelRatio == undefined)
        pixelRatio = 1;
      zm = zm / pixelRatio;
      if (inHeight != 240 && inWidth != 320 && zm > 1)
      {
        if ((inWidth / zm) < 480)
        {
          zm = zm / 2;
        }
      }
    }
    zm = zm / 2;
  }
  else
  {
    if (inHeight == 240 && inWidth == 320)
    {
      //window.requestAnimationFrame(setZoomed);
      setTimeout('setZoomed(' + a + ',' + b + ')', 500);
      return false;
    }
    else
    {
      zm = inHeight / window.document.body.firstElementChild.clientHeight;
    }
  }
  if (zm > 0)
  {
    document.body.style.zoom = zm * 100 + '%';
    if (userAgent.indexOf("trident") != -1)
    {
      zm = Math.round( zm * 100);
      document.body.style.zoom = zm + '%';
      if (zm  > 98 && zm < 102)
        zm = 100;
      document.body.style.width = Math.round(100 * inWidth / zm + 1) + "px";
      //document.body.style.width = 100 / zm + "%";
    }
    else
    if (userAgent.indexOf("android 4") == -1)
      document.body.style["font-size"] = document.body.style.zoom;
  }
  timeoutSetZoomed(b);
}

function timeoutSetZoomed(b) {
  count_setZoomed++;
  window.clearTimeout(timer_setZoomed);
  if (count_setZoomed < 10)
  {
    timer_setZoomed = window.setTimeout('setZoomed(0,' + b + ')', 500);
  }
  else
  {
    timer_setZoomed = window.setTimeout('setZoomed(0,' + b + ')', 1000 * count_setZoomed);
  }
}

function isIpadNewFunc() {
  var IsiPad = navigator.userAgent.indexOf("iPad") != -1 ;
  if(IsiPad)
  {
    var ratio = window.devicePixelRatio;
    if(ratio != undefined)
    {
      ratio = parseInt(ratio);
      if(ratio >= 2)
        return true;
    }
  }
  return false;
}

function getRealSize() {
  var ret = 0;
  var pixelRatio = window.devicePixelRatio;
  if(pixelRatio == undefined)
    pixelRatio = 1;
  if (window.screen.width == 0)
  {
    ret = document.width;
    if (pixelRatio == 2)
      ret = ret * pixelRatio;
  }
  else
  if (window.outerWidth == 0)
  {
    ret = window.innerWidth;
  }
  else
  if(window.outerWidth != window.innerWidth)
  {
    ret = document.documentElement.clientWidth;
  }
  else
  {
    ret = window.screen.width;
  }
  return ret;
}

function convertLink(link, hastrk3, sub_campaign)
{
  var tmp,
    g5storecode = "";
  if (typeof window['g5storecode_reg'] == 'undefined')
  {
    var platform = window.localStorage.getItem("xpromo.platform").toLowerCase()||"iphone";
    var regArr = {
      'android': /\/details\?id=(.*)$/,
      'kindle': /\/android\?p=(.*)$/,
      'iphone': /itunes.*id(\d+)\?mt=/,
      'nook': /barnesandnoble.*\?ean=(\d*)/,
      'winrt': /\?PFN=(.*)$/,
      'winphone': /\?appid=(.*)$/
    };
    regArr['ipad'] = regArr['iphone'];
    regArr['mac'] = regArr['iphone'];
    if (platform == "android")
    {
      tmp = window.localStorage.getItem("xpromo.id");
      if (tmp)
      {
        tmp = tmp.split('.');
        if (tmp.indexOf('amzn') > -1)
          platform = "kindle";
      }
    }
    window['g5storecode_reg'] = '';
    if (regArr.hasOwnProperty(platform))
      window['g5storecode_reg'] = regArr[platform];
  }

  if (window['g5storecode_reg'])
  {
    tmp = link.match(window['g5storecode_reg']);

    if (tmp != null && tmp[1] != null)
    {
      if (tmp[1].indexOf('&') != -1)
        tmp[1] = tmp[1].slice(0, tmp[1].indexOf('&'));
      g5storecode = "&g5storecode=" + tmp[1];
    }
  }

  if (link.indexOf('@ext(') == 0)
  {
    link = link.slice(5, link.length - 1);

    if (window.localStorage.getItem('xpromo.enable.affiliates') == 1)
    {
      if (link.indexOf('phobos.apple.com') != -1 || link.indexOf('itunes.apple.com') != -1)
      {
        if ( hastrk3 != undefined && hastrk3 != "" )
        {
          sub_campaign = sub_campaign || "&sub_campaign=more_games";
          link = hastrk3 + sub_campaign + "&url=" + encodeURIComponent(link + "&at=11lbfd");
        }
        else
        {
          link = link + "&at=11lbfd";
        }
      }
    }
    if (window.KDWebWindow &&
        window.KDWebWindow.shouldLoad)
      link = "javascript:simulateClickExt('" + link + "')";
    else
      link = "@ext(" + link + g5storecode + ")";
  }

  return link;
}

function getCountryLang() {
  setTimeout(function(){
    var SERVICE_ADR = 'http://xpromo.g5e.com/v1/service/geolang.php';
    with (new XMLHttpRequest())
    {
      open("GET", SERVICE_ADR, true);
      onreadystatechange = function()
      {
        if (readyState != 4)
          return;

        var text;
        if (status == 200 || responseText) // for local GET to work
        {
          setCountryLang(responseText);
        }
        else
        {
          var t = document.createElement("script");
          t.src = SERVICE_ADR + '?cb=setCountryLang';
          document.body.appendChild(t);
        }
      }
      send(null);
    }

  }, 1000);
}

function setCountryLang(a) {
  var text;
  if (typeof a == 'string')
  {
    text = JSON.parse(a);
  }
  else
  if (typeof a != 'array')
  {
    text = $.map(a, function(value, index) {
      return [value];
    });
  }
  if (text instanceof Array)
  {
    text = text.join('|');
    if (text.length > 0)
      window.localStorage.setItem("country_lang", text);
  }
}

function getActiveTab(_tp) {
  var ret = 1;
  if (typeof _tp == 'undefined')
    return ret;
  //hack use function only for com.g5e.bravetribe
  var self_id = window.localStorage.getItem('xpromo.id');
  if (self_id == null)
    window.localStorage.getItem('xpromo.games.self.id');
  if (typeof self_id == 'string')
  {
    self_id = self_id.split('.');
    if (self_id.length > 2)
    {
      if (['bravetribe', 'lettersfromnowherepg'].indexOf(self_id[2]) == -1)
        return ret;
    }
  }
  //end hack
  if (typeof window['activeTab'] != 'undefined')
    return window['activeTab'];
  var num_element = ['lp', 'mg'].indexOf(_tp);
  if (num_element == -1)
    return ret;
  var tmp = window.localStorage.getItem('active_tab');
  if (tmp != null)
  {
    tmp = tmp.split('|');
    if (typeof tmp[num_element] == 'undefined')
      tmp[num_element] = 0;
    tmp[num_element] = parseInt(tmp[num_element]);
    if (isNaN(tmp[num_element]))
      tmp[num_element] = 0;
    if (tmp[num_element] < 0 || tmp[num_element] > 1)
      tmp[num_element] = 0;
    ret = 1 - tmp[num_element];
  }
  else
  {
    tmp = [];
  }
  tmp[num_element] = ret;
  window.localStorage.setItem('active_tab', tmp.join('|'));
  window['activeTab'] = ret;
  return ret;
}